<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ComputerColorDialog</name>
    <message>
        <source>Computer Colors</source>
        <translation>Computer-Farben</translation>
    </message>
    <message>
        <source>Computer plays:</source>
        <translation>Computer spielt:</translation>
    </message>
    <message>
        <source>&amp;Blue</source>
        <translation>&amp;Blau</translation>
    </message>
    <message>
        <source>&amp;Green</source>
        <translation>&amp;Grün</translation>
    </message>
    <message>
        <source>&amp;Yellow</source>
        <translation>G&amp;elb</translation>
    </message>
    <message>
        <source>&amp;Red</source>
        <translation>&amp;Rot</translation>
    </message>
    <message>
        <source>&amp;Blue/Red</source>
        <translation>&amp;Blau/Rot</translation>
    </message>
    <message>
        <source>&amp;Yellow/Green</source>
        <translation>&amp;Gelb/Grün</translation>
    </message>
</context>
<context>
    <name>GameInfoDialog</name>
    <message>
        <source>Game Info</source>
        <translation>Spielinformation</translation>
    </message>
    <message>
        <source>Player &amp;Blue:</source>
        <oldsource>Player Blue:</oldsource>
        <translation>Spieler &amp;Blau:</translation>
    </message>
    <message>
        <source>Player &amp;Green:</source>
        <oldsource>Player Green:</oldsource>
        <translation>Spieler &amp;Grün:</translation>
    </message>
    <message>
        <source>Player &amp;Yellow:</source>
        <oldsource>Player Yellow:</oldsource>
        <translation>Spieler G&amp;elb:</translation>
    </message>
    <message>
        <source>Player &amp;Red:</source>
        <oldsource>Player Red:</oldsource>
        <translation>Spieler &amp;Rot:</translation>
    </message>
    <message>
        <source>Player &amp;Blue/Red:</source>
        <oldsource>Player Blue/Red:</oldsource>
        <translation>Spieler &amp;Blau/Rot:</translation>
    </message>
    <message>
        <source>Player &amp;Yellow/Green:</source>
        <oldsource>Player Yellow/Green:</oldsource>
        <translation>Spieler &amp;Gelb/Grün:</translation>
    </message>
    <message>
        <source>&amp;Date:</source>
        <oldsource>Date:</oldsource>
        <translation>&amp;Datum:</translation>
    </message>
    <message>
        <source>&amp;Time limits:</source>
        <translation>Bedenk&amp;zeit:</translation>
    </message>
    <message>
        <source>&amp;Event:</source>
        <translation>&amp;Veranstaltung:</translation>
    </message>
    <message>
        <source>R&amp;ound:</source>
        <translation>R&amp;unde:</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Show previous page in history</source>
        <translation>Die vorherige Seite in der Chronik anzeigen</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <source>Show next page in history</source>
        <translation>Die nächste Seite in der Chronik anzeigen</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Inhalt</translation>
    </message>
    <message>
        <source>Show table of contents</source>
        <translation>Das Inhaltsverzeichnis anzeigen</translation>
    </message>
</context>
<context>
    <name>InitialRatingDialog</name>
    <message>
        <source>Initial Rating</source>
        <translation>Anfangswertung</translation>
    </message>
    <message>
        <source>You have not yet played rated games in this game variant. Estimate your playing strength to initialize your rating.</source>
        <translation>Sie haben noch keine gewerteten Spiele in dieser Spielvariante gespielt. Schätzen Sie Ihre Spielstärke, um Ihre Wertung zu initialisieren.</translation>
    </message>
    <message>
        <source>Beginner</source>
        <translation>Anfänger</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Experte</translation>
    </message>
    <message>
        <source>Your initial rating: %1</source>
        <translation>Ihre Anfangswertung: %1</translation>
    </message>
</context>
<context>
    <name>Util</name>
    <message>
        <source>Blue</source>
        <translation>Blau</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Grün</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Gelb</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Rot</translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation>Blau/Rot</translation>
    </message>
    <message>
        <source>Yellow/Green</source>
        <translation>Gelb/Grün</translation>
    </message>
</context>
</TS>
